@@ -47,14 +47,6 @@ pub fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
         parquet_column_encoding,
     } = opt;
 
-    // Convert the input strings into parameters suitable to for use with ODBC.
-    let params: Vec<_> = parameters
-        .iter()
-        .map(|param| param.as_str().into_parameter())
-        .collect();
-
-    let odbc_conn = open_connection(&environment, connect_opts)?;
-
     let batch_size = match (*batch_size_row, *batch_size_mib) {
         (Some(rows), None) => BatchSizeLimit::Rows(rows),
         (None, Some(mib)) => BatchSizeLimit::Bytes(mib as usize * 1024 * 1024),
@@ -68,6 +60,14 @@ pub fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
         }
     };
 
+    // Convert the input strings into parameters suitable for use with ODBC.
+    let params: Vec<_> = parameters
+        .iter()
+        .map(|param| param.as_str().into_parameter())
+        .collect();
+
+    let odbc_conn = open_connection(&environment, connect_opts)?;
+
     let parquet_format_options = ParquetFormatOptions {
         column_compression_default: *column_compression_default,
         column_encodings: parquet_column_encoding.clone(),
@@ -130,9 +130,11 @@ fn cursor_to_parquet(
             let rows = (num_bytes / total_mem_usage_per_row).try_into().unwrap();
             if rows == 0 {
                 bail!(
-                    "Memory required to hold a single row is to larger than the limit. Memory \
-                    Limit: {} bytes, Memory per row: {} bytes.\nYou can use either \n
-                    --batch-size-row or --batch-size-mib to raise the limit.",
+                    "Memory required to hold a single row is larger than the limit. Memory Limit: \
+                    {} bytes, Memory per row: {} bytes.\nYou can use either '--batch-size-row' or \
+                    '--batch-size-mib' to raise the limit. You may also try more verbose output to \
+                    see which columns require so much memory and consider casting them into \
+                    something smaller.",
                     num_bytes,
                     total_mem_usage_per_row
                 )
@@ -157,7 +159,6 @@ fn cursor_to_parquet(
 
     let mut writer = ParquetWriter::new(
         path,
-        batch_size_row,
         parquet_schema.clone(),
         batches_per_file,
         parquet_format_options,
@@ -580,7 +581,6 @@ struct ParquetWriter<'p> {
 impl<'p> ParquetWriter<'p> {
     pub fn new(
         path: &'p Path,
-        batch_size: u32,
         schema: Arc<Type>,
         batches_per_file: u32,
         format_options: ParquetFormatOptions,
@@ -589,7 +589,6 @@ impl<'p> ParquetWriter<'p> {
         // Seems to also work fine without setting the batch size explicitly, but what the heck. Just to
         // be on the safe side.
         let mut wpb = WriterProperties::builder()
-            .set_write_batch_size(batch_size as usize)
             .set_compression(format_options.column_compression_default);
         for (column_name, encoding) in format_options.column_encodings {
             let col = ColumnPath::new(vec![column_name]);
